@@ -5,7 +5,7 @@
 #
 # Copyright 2014-2016 VeriSign, Inc.
 #
-# Copyright 2016-2021 Casey Deccio
+# Copyright 2016-2024 Casey Deccio
 #
 # DNSViz is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,6 +30,9 @@ import socket
 
 INTERFACE_RE = re.compile(r'%[a-z0-9]+$')
 
+class LinkLocalAddress(ValueError):
+    pass
+
 class IPAddr(str):
     def __new__(cls, string):
         # python 2/3 compatibility
@@ -38,7 +41,8 @@ class IPAddr(str):
         if ':' in string:
             af = socket.AF_INET6
             vers = 6
-            string = INTERFACE_RE.sub('', string)
+            if INTERFACE_RE.search(string) is not None:
+                raise LinkLocalAddress()
         else:
             af = socket.AF_INET
             vers = 4
